#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from tempor.cli import main

if __name__ == "__main__":
    main()
